client

package
v0.53.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 10, 2026 License: Apache-2.0 Imports: 10 Imported by: 1

Documentation

Overview

Package client implements the client interfaces defined in the anytype package

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewClient

func NewClient(options anytype.ClientOptions) anytype.Client

Types

type AddObjectsToListRequest added in v0.4.0

type AddObjectsToListRequest struct {
	Objects []string `json:"objects"`
}

type AuthClientImpl

type AuthClientImpl struct {
	// contains filtered or unexported fields
}

func (*AuthClientImpl) CreateApiKey added in v0.4.0

func (ac *AuthClientImpl) CreateApiKey(ctx context.Context, challengeID string, code string) (*anytype.CreateApiKeyResponse, error)

CreateApiKey completes the authentication flow by providing a code

func (*AuthClientImpl) CreateChallenge added in v0.4.0

func (ac *AuthClientImpl) CreateChallenge(ctx context.Context, appName string) (*anytype.CreateChallengeResponse, error)

type ClientImpl

type ClientImpl struct {
	// contains filtered or unexported fields
}

func (*ClientImpl) Auth

func (c *ClientImpl) Auth() anytype.AuthClient

func (*ClientImpl) Search

func (c *ClientImpl) Search() anytype.SearchClient

func (*ClientImpl) Space

func (c *ClientImpl) Space(spaceID string) anytype.SpaceContext

func (*ClientImpl) Spaces

func (c *ClientImpl) Spaces() anytype.SpaceClient

type CreateApiKeyRequest added in v0.4.0

type CreateApiKeyRequest struct {
	ChallengeID string `json:"challenge_id"`
	Code        string `json:"code"`
}

type CreateChallengeRequest added in v0.4.0

type CreateChallengeRequest struct {
	AppName string `json:"app_name"`
}

type ListContextImpl

type ListContextImpl struct {
	// contains filtered or unexported fields
}

func (*ListContextImpl) Object

func (lc *ListContextImpl) Object(objectID string) anytype.ObjectListContext

func (*ListContextImpl) Objects

func (*ListContextImpl) View

func (lc *ListContextImpl) View(viewID string) anytype.ViewContext

func (*ListContextImpl) Views

func (lc *ListContextImpl) Views() anytype.ViewClient

type MemberClientImpl

type MemberClientImpl struct {
	// contains filtered or unexported fields
}

func (*MemberClientImpl) List

type MemberContextImpl

type MemberContextImpl struct {
	// contains filtered or unexported fields
}

func (*MemberContextImpl) Get

type ObjectClientImpl

type ObjectClientImpl struct {
	// contains filtered or unexported fields
}

func (*ObjectClientImpl) Create

func (*ObjectClientImpl) List

func (oc *ObjectClientImpl) List(ctx context.Context, opts ...anytype.ListOption) ([]anytype.Object, error)

type ObjectContextImpl

type ObjectContextImpl struct {
	// contains filtered or unexported fields
}

func (*ObjectContextImpl) Delete

func (*ObjectContextImpl) Get

func (*ObjectContextImpl) Update

type ObjectListClientImpl

type ObjectListClientImpl struct {
	// contains filtered or unexported fields
}

func (*ObjectListClientImpl) Add

func (olc *ObjectListClientImpl) Add(ctx context.Context, objectIDs []string) error

type ObjectListContextImpl

type ObjectListContextImpl struct {
	// contains filtered or unexported fields
}

func (*ObjectListContextImpl) Remove

func (olc *ObjectListContextImpl) Remove(ctx context.Context) error

type ObjectViewClientImpl

type ObjectViewClientImpl struct {
	// contains filtered or unexported fields
}

func (*ObjectViewClientImpl) List

type PropertyContextImpl added in v0.53.1

type PropertyContextImpl struct {
	// contains filtered or unexported fields
}

func (*PropertyContextImpl) Delete added in v0.53.1

func (*PropertyContextImpl) Get added in v0.53.1

func (*PropertyContextImpl) Tag added in v0.53.1

func (*PropertyContextImpl) Tags added in v0.53.1

func (*PropertyContextImpl) Update added in v0.53.1

type SearchClientImpl

type SearchClientImpl struct {
	// contains filtered or unexported fields
}

func (*SearchClientImpl) Search

Search searches for objects across all spaces

type SpaceClientImpl

type SpaceClientImpl struct {
	// contains filtered or unexported fields
}

func (*SpaceClientImpl) Create

func (*SpaceClientImpl) List

type SpaceContextImpl

type SpaceContextImpl struct {
	// contains filtered or unexported fields
}

func (*SpaceContextImpl) Get

func (*SpaceContextImpl) List

func (sc *SpaceContextImpl) List(listID string) anytype.ListContext

func (*SpaceContextImpl) Member

func (sc *SpaceContextImpl) Member(memberID string) anytype.MemberContext

func (*SpaceContextImpl) Members

func (sc *SpaceContextImpl) Members() anytype.MemberClient

func (*SpaceContextImpl) Object

func (sc *SpaceContextImpl) Object(objectID string) anytype.ObjectContext

func (*SpaceContextImpl) Objects

func (sc *SpaceContextImpl) Objects() anytype.ObjectClient

func (*SpaceContextImpl) Properties added in v0.53.1

func (sc *SpaceContextImpl) Properties() anytype.SpacePropertyClient

func (*SpaceContextImpl) Property added in v0.53.1

func (sc *SpaceContextImpl) Property(propertyID string) anytype.PropertyContext

func (*SpaceContextImpl) Search

func (*SpaceContextImpl) Type

func (sc *SpaceContextImpl) Type(typeID string) anytype.TypeContext

func (*SpaceContextImpl) Types

func (sc *SpaceContextImpl) Types() anytype.TypeClient

func (*SpaceContextImpl) Update added in v0.53.1

type SpacePropertyClientImpl added in v0.53.1

type SpacePropertyClientImpl struct {
	// contains filtered or unexported fields
}

func (*SpacePropertyClientImpl) Create added in v0.53.1

func (*SpacePropertyClientImpl) List added in v0.53.1

type TagClientImpl added in v0.53.1

type TagClientImpl struct {
	// contains filtered or unexported fields
}

func (*TagClientImpl) Create added in v0.53.1

func (*TagClientImpl) List added in v0.53.1

func (tc *TagClientImpl) List(ctx context.Context) ([]anytype.Tag, error)

type TagContextImpl added in v0.53.1

type TagContextImpl struct {
	// contains filtered or unexported fields
}

func (*TagContextImpl) Delete added in v0.53.1

func (tc *TagContextImpl) Delete(ctx context.Context) (*anytype.TagResponse, error)

func (*TagContextImpl) Get added in v0.53.1

func (*TagContextImpl) Update added in v0.53.1

type TemplateClientImpl

type TemplateClientImpl struct {
	// contains filtered or unexported fields
}

func (*TemplateClientImpl) List

type TemplateContextImpl

type TemplateContextImpl struct {
	// contains filtered or unexported fields
}

func (*TemplateContextImpl) Get

type TypeClientImpl

type TypeClientImpl struct {
	// contains filtered or unexported fields
}

func (*TypeClientImpl) Create added in v0.3.4

func (*TypeClientImpl) Get

func (tc *TypeClientImpl) Get(ctx context.Context, typeKey string) (*anytype.Type, error)

func (*TypeClientImpl) GetKeyByName

func (tc *TypeClientImpl) GetKeyByName(ctx context.Context, name string) (string, error)

GetKeyByName looks up a type key by its name

func (*TypeClientImpl) List

func (tc *TypeClientImpl) List(ctx context.Context) ([]anytype.Type, error)

type TypeContextImpl

type TypeContextImpl struct {
	// contains filtered or unexported fields
}

func (*TypeContextImpl) Delete added in v0.53.1

func (*TypeContextImpl) Get

func (*TypeContextImpl) Template

func (tc *TypeContextImpl) Template(templateID string) anytype.TemplateContext

func (*TypeContextImpl) Templates

func (tc *TypeContextImpl) Templates() anytype.TemplateClient

func (*TypeContextImpl) Update added in v0.53.1

type ViewClientImpl

type ViewClientImpl struct {
	// contains filtered or unexported fields
}

func (*ViewClientImpl) List

type ViewContextImpl

type ViewContextImpl struct {
	// contains filtered or unexported fields
}

func (*ViewContextImpl) Objects

Jump to